use strict;
use warnings;


package AeroCrs::Response::Booking;
use Class::Struct;
use Data::Dumper;

our @ISA = qw(AeroCrs::Response);

sub pnrref
{
  my $self = shift;
  return $self->{_response}->{booking}{pnrref};
}

sub status
{
  my $self = shift;
  return $self->{_response}->{booking}{status};
}

sub bookingconfirmation
{
  my $self = shift;
  return $self->{_response}->{booking}{bookingconfirmation};
}

sub invoicenumber
{
  my $self = shift;
  return $self->{_response}->{booking}{invoicenumber};
}

sub ticketnumber
{
  my $self = shift;
  return $self->{_response}->{booking}{ticketnumber};
}

sub _balance
{
  my $self = shift;

  struct Balance => {
    outstanding => '$',
    total       => '$',
  };

  my $balance = Balance->new();

  $balance->outstanding($self->{_response}->{booking}{Balanceinformation}{PNRoutstandingpayment});
  $balance->total($self->{_response}->{booking}{Balanceinformation}{PNRtotal});

  return $balance;
}

sub balance
{
  my $self = shift;
  unless (defined($self->{_balance})) {
    $self->{_balance} = $self->_balance;
  }
  return $self->{_balance};
}

sub _passengers
{
  my $self = shift;

  struct Passenger => {
    paxtitle  => '$',
    firstname => '$',
    lastname  => '$',
  };

  my @passengers;

  foreach my $passenger (values $self->{_response}->{booking}{passengers}{passenger}) {
    my $p = Passenger->new();

    $p->paxtitle($passenger->{paxtitle});
    $p->firstname($passenger->{firstname});
    $p->lastname($passenger->{lastname});

    push @passengers, $p;
  }
  return \@passengers;
}
 
sub passengers
{
  my $self = shift;
  unless (defined($self->{_passengers})) {
    $self->{_passengers} = $self->_passengers;
  }
  return @{$self->{_passengers}};
}

sub _flights
{
  my $self = shift;

  struct Flight => {
    airline    => '$',
    invid      => '$',
    invpricing => '$',
    flightdate => '$',
    arrive     => '$',
    from       => '$',
    number     => '$',
    depart     => '$',
    to         => '$'
  };

  my @flights;

  foreach my $flight (values $self->{_response}->{booking}{flights}{flight}) {
    my $f = Flight->new();

    $f->airline($flight->{airline});
    $f->invid($flight->{invid});
    $f->invpricing($flight->{invpricing});
    $f->flightdate($flight->{flightdate});
    $f->arrive($flight->{arrive});
    $f->from($flight->{from});
    $f->number($flight->{number});
    $f->depart($flight->{depart});
    $f->to($flight->{to});

    push @flights, $f;
  }
  return \@flights;
}

sub flights
{
  my $self = shift;
  unless (defined($self->{_flights})) {
    $self->{_flights} = $self->_flights;
  }
  return @{$self->{_flights}};
}

sub _remarks
{
  my $self = shift;

  struct Remark => {text => '$'};
  my @remarks;

  foreach my $remark (values $self->{_response}->{booking}{remarks}{remark}) {
    my $r = Remark->new();

    $r->text($remark->{text});

    push @remarks, $r;
  }
  return \@remarks;
}

sub remarks
{
  my $self = shift;
  unless (defined($self->{_remarks})) {
    $self->{_remarks} = $self->_remarks;
  }
  return @{$self->{_remarks}};
}

1;
